@@ -1,3 +1,6 @@
+import os
+import sys
+
 from pyatmo.auth import ALL_SCOPES, ClientAuth
 from pyatmo.camera import CameraData
 from pyatmo.exceptions import NoDevice
@@ -5,56 +8,58 @@ from pyatmo.public_data import PublicData
 from pyatmo.thermostat import HomeData
 from pyatmo.weather_station import WeatherStationData
 
+LON_NE = 6.221652
+LAT_NE = 46.610870
+LON_SW = 6.217828
+LAT_SW = 46.596485
+
 
 def main():
-    import sys
-
     try:
-        import os
-
         if (
             os.environ["CLIENT_ID"]
             and os.environ["CLIENT_SECRET"]
             and os.environ["USERNAME"]
             and os.environ["PASSWORD"]
         ):
-            CLIENT_ID = os.environ["CLIENT_ID"]
-            CLIENT_SECRET = os.environ["CLIENT_SECRET"]
-            USERNAME = os.environ["USERNAME"]
-            PASSWORD = os.environ["PASSWORD"]
+            client_id = os.environ["CLIENT_ID"]
+            client_secret = os.environ["CLIENT_SECRET"]
+            username = os.environ["USERNAME"]
+            password = os.environ["PASSWORD"]
     except KeyError:
         sys.stderr.write(
-            "No credentials passed to pyatmo.py (client_id, client_secret, username, password)\n"
+            "No credentials passed to pyatmo.py (client_id, client_secret, "
+            "username, password)\n"
         )
         sys.exit(1)
 
-    authorization = ClientAuth(
-        clientId=CLIENT_ID,
-        clientSecret=CLIENT_SECRET,
-        username=USERNAME,
-        password=PASSWORD,
+    auth = ClientAuth(
+        client_id=client_id,
+        client_secret=client_secret,
+        username=username,
+        password=password,
         scope=" ".join(ALL_SCOPES),
     )
 
     try:
-        WeatherStationData(authorization)
+        WeatherStationData(auth)
     except NoDevice:
         if sys.stdout.isatty():
             print("pyatmo.py : warning, no weather station available for testing")
 
     try:
-        CameraData(authorization)
+        CameraData(auth)
     except NoDevice:
         if sys.stdout.isatty():
             print("pyatmo.py : warning, no camera available for testing")
 
     try:
-        HomeData(authorization)
+        HomeData(auth)
     except NoDevice:
         if sys.stdout.isatty():
             print("pyatmo.py : warning, no thermostat available for testing")
 
-    PublicData(authorization)
+    PublicData(auth, LAT_NE, LON_NE, LAT_SW, LON_SW)
 
     # If we reach this line, all is OK
 
