@@ -1,22 +1,22 @@
 import logging
 from json import JSONDecodeError
 from time import sleep
-from typing import Callable, Dict, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Optional, Tuple, Union
 
 import requests
-from oauthlib.oauth2 import LegacyApplicationClient, TokenExpiredError
-from requests_oauthlib import OAuth2Session
+from oauthlib.oauth2 import LegacyApplicationClient, TokenExpiredError  # type: ignore
+from requests_oauthlib import OAuth2Session  # type: ignore
 
-from .exceptions import ApiError
-from .helpers import _BASE_URL, ERRORS
+from pyatmo.exceptions import ApiError
+from pyatmo.helpers import _BASE_URL, ERRORS
 
 LOG = logging.getLogger(__name__)
 
 # Common definitions
-_AUTH_REQ = _BASE_URL + "oauth2/token"
-_AUTH_URL = _BASE_URL + "oauth2/authorize"
-_WEBHOOK_URL_ADD = _BASE_URL + "api/addwebhook"
-_WEBHOOK_URL_DROP = _BASE_URL + "api/dropwebhook"
+AUTH_REQ = _BASE_URL + "oauth2/token"
+AUTH_URL = _BASE_URL + "oauth2/authorize"
+WEBHOOK_URL_ADD = _BASE_URL + "api/addwebhook"
+WEBHOOK_URL_DROP = _BASE_URL + "api/dropwebhook"
 
 
 # Possible scops
@@ -35,27 +35,9 @@ ALL_SCOPES = [
 ]
 
 
-class NetatmOAuth2:
+class NetatmoOAuth2:
     """
     Handle authentication with OAuth2
-
-    :param client_id: Application client ID delivered by Netatmo on dev.netatmo.com
-    :param client_secret: Application client secret delivered by Netatmo on dev.netatmo.com
-    :param redirect_uri: Redirect URI where to the authorization server will redirect with an authorization code
-    :param token: Authorization token
-    :param token_updater: Callback when the token is updated
-    :param scope:
-        read_station: to retrieve weather station data (Getstationsdata, Getmeasure)
-        read_camera: to retrieve Welcome data (Gethomedata, Getcamerapicture)
-        access_camera: to access the camera, the videos and the live stream
-        write_camera: to set home/away status of persons (Setpersonsaway, Setpersonshome)
-        read_thermostat: to retrieve thermostat data (Getmeasure, Getthermostatsdata)
-        write_thermostat: to set up the thermostat (Syncschedule, Setthermpoint)
-        read_presence: to retrieve Presence data (Gethomedata, Getcamerapicture)
-        access_presence: to access the live stream, any video stored on the SD card and to retrieve Presence's lightflood status
-        read_homecoach: to retrieve Home Coache data (Gethomecoachsdata)
-        read_smokedetector: to retrieve the smoke detector status (Gethomedata)
-        Several value can be used at the same time, ie: 'read_station read_camera'
     """
 
     def __init__(
@@ -66,20 +48,40 @@ class NetatmOAuth2:
         token: Optional[Dict[str, str]] = None,
         token_updater: Optional[Callable[[str], None]] = None,
         scope: Optional[str] = "read_station",
-    ):
+    ) -> None:
+        """Initialize self.
+
+        Keyword Arguments:
+            client_id {str} -- Application client ID delivered by Netatmo on dev.netatmo.com (default: {None})
+            client_secret {str} -- Application client secret delivered by Netatmo on dev.netatmo.com (default: {None})
+            redirect_uri {Optional[str]} -- Redirect URI where to the authorization server will redirect with an authorization code (default: {None})
+            token {Optional[Dict[str, str]]} -- Authorization token (default: {None})
+            token_updater {Optional[Callable[[str], None]]} -- Callback when the token is updated (default: {None})
+            scope {Optional[str]} -- List of scopes (default: {"read_station"})
+                read_station: to retrieve weather station data (Getstationsdata, Getmeasure)
+                read_camera: to retrieve Welcome data (Gethomedata, Getcamerapicture)
+                access_camera: to access the camera, the videos and the live stream
+                write_camera: to set home/away status of persons (Setpersonsaway, Setpersonshome)
+                read_thermostat: to retrieve thermostat data (Getmeasure, Getthermostatsdata)
+                write_thermostat: to set up the thermostat (Syncschedule, Setthermpoint)
+                read_presence: to retrieve Presence data (Gethomedata, Getcamerapicture)
+                access_presence: to access the live stream, any video stored on the SD card and to retrieve Presence's lightflood status
+                read_homecoach: to retrieve Home Coache data (Gethomecoachsdata)
+                read_smokedetector: to retrieve the smoke detector status (Gethomedata)
+                Several values can be used at the same time, ie: 'read_station read_camera'
+        """
         self.client_id = client_id
         self.client_secret = client_secret
         self.redirect_uri = redirect_uri
         self.token_updater = token_updater
+
         if token:
             self.scope = " ".join(token["scope"])
+
         else:
             self.scope = " ".join(ALL_SCOPES) if not scope else scope
 
-        self.extra = {
-            "client_id": self.client_id,
-            "client_secret": self.client_secret,
-        }
+        self.extra = {"client_id": self.client_id, "client_secret": self.client_secret}
 
         self._oauth = OAuth2Session(
             client_id=self.client_id,
@@ -91,7 +93,7 @@ class NetatmOAuth2:
 
     def refresh_tokens(self) -> Dict[str, Union[str, int]]:
         """Refresh and return new tokens."""
-        token = self._oauth.refresh_token(_AUTH_REQ, **self.extra)
+        token = self._oauth.refresh_token(AUTH_REQ, **self.extra)
 
         if self.token_updater is not None:
             self.token_updater(token)
@@ -99,18 +101,20 @@ class NetatmOAuth2:
         return token
 
     def post_request(
-        self, url: str, params: Optional[Dict[str, str]] = None, timeout: int = 5
-    ):
+        self, url: str, params: Optional[Dict] = None, timeout: int = 5,
+    ) -> Any:
         """Wrapper for post requests."""
+        resp = None
         if not params:
             params = {}
 
         if "json" in params:
-            json_params = params.pop("json")
+            json_params: Optional[str] = params.pop("json")
+
         else:
             json_params = None
 
-        if "http://" in url:
+        if "https://" not in url:
             try:
                 resp = requests.post(url, data=params, timeout=timeout)
             except requests.exceptions.ChunkedEncodingError:
@@ -119,21 +123,25 @@ class NetatmOAuth2:
                 LOG.debug("Connection to %s timed out", url)
             except requests.exceptions.ConnectionError:
                 LOG.debug("Remote end closed connection without response (%s)", url)
+
         else:
 
-            def query(url, params, timeout, retries):
+            def query(url: str, params: Dict, timeout: int, retries: int) -> Any:
                 if retries == 0:
                     LOG.error("Too many retries")
                     return
+
                 try:
                     if json_params:
                         rsp = self._oauth.post(
                             url=url, json=json_params, timeout=timeout
                         )
+
                     else:
                         rsp = self._oauth.post(url=url, data=params, timeout=timeout)
 
                     return rsp
+
                 except (
                     TokenExpiredError,
                     requests.exceptions.ReadTimeout,
@@ -143,13 +151,15 @@ class NetatmOAuth2:
                     # Sleep for 1 sec to prevent authentication related
                     # timeouts after a token refresh.
                     sleep(1)
-                    return query(url, params, timeout, retries - 1)
+                    return query(url, params, timeout * 2, retries - 1)
 
             resp = query(url, params, timeout, 3)
 
         if resp is None:
             LOG.debug("Resp is None - %s", resp)
-        elif not resp.ok:
+            return None
+
+        if not resp.ok:
             LOG.debug("The Netatmo API returned %s", resp.status_code)
             LOG.debug("Netato API error: %s", resp.content)
             try:
@@ -160,6 +170,7 @@ class NetatmOAuth2:
                     f"({resp.json()['error']['code']}) "
                     f"when accessing '{url}'"
                 )
+
             except JSONDecodeError:
                 raise ApiError(
                     f"{resp.status_code} - "
@@ -168,17 +179,19 @@ class NetatmOAuth2:
                 )
 
         try:
-            return (
-                resp.json()
-                if "application/json" in resp.headers.get("content-type")
-                else resp.content
-            )
+            if "application/json" in resp.headers.get("content-type", []):
+                return resp.json()
+
+            if resp.content not in [b"", b"None"]:
+                return resp.content
+
         except (TypeError, AttributeError):
             LOG.debug("Invalid response %s", resp)
+
         return None
 
     def get_authorization_url(self, state: Optional[str] = None) -> Tuple[str, str]:
-        return self._oauth.authorization_url(_AUTH_URL, state)
+        return self._oauth.authorization_url(AUTH_URL, state)
 
     def request_token(
         self, authorization_response: Optional[str] = None, code: Optional[str] = None
@@ -191,25 +204,25 @@ class NetatmOAuth2:
         :return: A token dict
         """
         return self._oauth.fetch_token(
-            _AUTH_REQ,
+            AUTH_REQ,
             authorization_response=authorization_response,
             code=code,
             client_secret=self.client_secret,
             include_client_id=True,
         )
 
-    def addwebhook(self, webhook_url):
-        postParams = {"url": webhook_url}
-        resp = self.post_request(_WEBHOOK_URL_ADD, postParams)
+    def addwebhook(self, webhook_url: str) -> None:
+        post_params = {"url": webhook_url}
+        resp = self.post_request(WEBHOOK_URL_ADD, post_params)
         LOG.debug("addwebhook: %s", resp)
 
-    def dropwebhook(self):
-        postParams = {"app_types": "app_security"}
-        resp = self.post_request(_WEBHOOK_URL_DROP, postParams)
+    def dropwebhook(self) -> None:
+        post_params = {"app_types": "app_security"}
+        resp = self.post_request(WEBHOOK_URL_DROP, post_params)
         LOG.debug("dropwebhook: %s", resp)
 
 
-class ClientAuth(NetatmOAuth2):
+class ClientAuth(NetatmoOAuth2):
     """
     Request authentication and keep access token available through token method. Renew it automatically if necessary
     Args:
@@ -232,17 +245,23 @@ class ClientAuth(NetatmOAuth2):
     """
 
     def __init__(
-        self, clientId, clientSecret, username, password, scope="read_station"
+        self,
+        client_id: str,
+        client_secret: str,
+        username: str,
+        password: str,
+        scope="read_station",
     ):
-        self._clientId = clientId
-        self._clientSecret = clientSecret
+        # pylint: disable=super-init-not-called
+        self._client_id = client_id
+        self._client_secret = client_secret
 
-        self._oauth = OAuth2Session(client=LegacyApplicationClient(client_id=clientId))
+        self._oauth = OAuth2Session(client=LegacyApplicationClient(client_id=client_id))
         self._oauth.fetch_token(
-            token_url=_AUTH_REQ,
+            token_url=AUTH_REQ,
             username=username,
             password=password,
-            client_id=clientId,
-            client_secret=clientSecret,
+            client_id=client_id,
+            client_secret=client_secret,
             scope=scope,
         )
